EduCube Client
==============

Python client for the EduCube educational satellite

Usage demo: https://asciinema.org/a/bv5gczed3p0txkwfe3ddb53z6

Features
--------
Provides a Web UI for interacting with the EduCube
Provides a CLI for interacting with the EduCube

Installation
------------
pip install educube_client

Contribute
----------

Support
-------

If you are having issues, please let us know.
Email: daniel.vagg at gmail.com

